# coding: utf-8

"""
    Isilon SDK

    Isilon SDK - Language bindings for the OneFS API

    OpenAPI spec version: 8.0
    Contact: sdk@isilon.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Custom setup.py for isilon_sdk packages.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""


import sys
from setuptools import setup, find_packages

NAME = "isi_sdk_8_0"
VERSION = "0.1.7"
LONG_DESCRIPTION = """\
About
-----

This package is part of the Isilon SDK. It includes language bindings
for easier programmatic access to the OneFS API for cluster
configuration (on your cluster this is the REST API made up of all the
URIs underneath https://[cluster]:8080/platform/\*, also called the
"Platform API" or PAPI").

Installation
------------

``pip install PKG_NAME``

Example program
---------------

Here's an example of using the Python PAPI bindings to retrieve a list
of NFS exports from your cluster:

.. code:: python

    import PKG_NAME
    from PKG_NAME.rest import ApiException
    from pprint import pprint
    import urllib3
    urllib3.disable_warnings()

    # configure username and password
    PKG_NAME.configuration.username = "YOUR_USERNAME"
    PKG_NAME.configuration.password = "YOUR_PASSWORD"
    PKG_NAME.configuration.verify_ssl = False

    # configure host
    host = "https://YOUR_CLUSTER_HOSTNAME_OR_NODE_IP_ADDRESS:8080"
    api_client = PKG_NAME.ApiClient(host)
    protocols_api = PKG_NAME.ProtocolsApi(api_client)

    # get all exports
    sort = "description"
    limit = 50
    dir = "ASC"
    try: 
        api_response = protocols_api.list_nfs_exports(sort=sort, limit=limit, dir=dir)
        pprint(api_response)
    except ApiException as e:
        print "Exception when calling ProtocolsApi->list_nfs_exports: %s" % e

There are more examples of coding to the Python PAPI bindings in the
```tests/`` <https://github.com/Isilon/isilon_sdk/tree/master/tests>`__
subdirectory of the repo. The tests currently run against a generic
isi\_sdk import which is how the bindings library is named by default if
you build your own bindings. If you want to run the tests against one of
the libraries you've downloaded from the prebuilt releases page, you
should change the ``import isi_sdk`` lines to ``import isi_sdk_7_2`` or
``import isi_sdk_8_0`` depending on which one you downloaded.

More info
---------

See the Github repo for more information:
https://github.com/isilon/isilon_sdk

"""



# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Isilon SDK",
    author_email="sdk@isilon.com",
    url="https://github.com/Isilon/isilon_sdk",
    keywords=["Swagger", "Isilon SDK"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=LONG_DESCRIPTION.replace('PKG_NAME', NAME)
)


